<?php

namespace App\Http\Livewire;

use App\Models\Animation;
use App\Models\User;
use Mediconesystems\LivewireDatatables\BooleanColumn;
use Mediconesystems\LivewireDatatables\Column;
use Mediconesystems\LivewireDatatables\DateColumn;
use Mediconesystems\LivewireDatatables\NumberColumn;
use Mediconesystems\LivewireDatatables\Http\Livewire\LivewireDatatable;

class AnimationUsers extends LivewireDatatable
{
    public $model = User::class;
    public $animationId/*, $animationUsers*/;

    public function mount($model = null, $include = [], $exclude = [], $hide = [], $dates = [], $times = [], $searchable = [], $sort = null, $hideHeader = null, $hidePagination = null, $perPage = null, $exportable = false, $hideable = false, $beforeTableSlot = false, $afterTableSlot = false, $params = [])
    {
        $this->animationId = $this->params;
//        $this->animationUsers = Animation::find($this->animationId)->users;
        parent::mount($model, $include, $exclude, $hide, $dates, $times, $searchable, $sort, $hideHeader, $hidePagination, $perPage, $exportable, $hideable, $beforeTableSlot, $afterTableSlot, $params);
    }

    public function builder()
    {
        return User::query()->leftJoin('animation_user', function ($join) {
            $join->on('animation_user.user_id', 'users.id')->where('animation_user.animation_id', '=', (int)$this->animationId);
        });
    }

    public function columns()
    {
        return [
            NumberColumn::name('id'),
            Column::name('name')->searchable(),
            Column::name('language')->filterable(['fr', 'en']),
            BooleanColumn::name('active')->filterable(),
            Column::name('subscription')->filterable(['basic', 'premium', 'gold']),
            DateColumn::name('created_at'),
            BooleanColumn::name('animation_user.id')->label('linked')->filterable(),
            Column::callback(['id', 'animation_user.id'], function ($id, $linked) {
                return view('livewire/animation-users-actions', ['id' => $id, 'linked' => $linked, 'animationId' => $this->animationId]);
            })->label('Actions'),
        ];
    }

    public function addUser($id)
    {
        Animation::find($this->animationId)->users()->attach($id);
    }

    public function deleteUser($id)
    {
        Animation::find($this->animationId)->users()->detach($id);
    }
}
