<?php

use App\Http\Livewire\AnimationEdit;
use App\Http\Livewire\AnimationsTable;
use App\Http\Livewire\AnimationUsers;
use App\Http\Livewire\UserAnimations;
use App\Http\Livewire\UserEdit;
use App\Http\Livewire\ResidentEdit;
use App\Models\Animation;
use App\Models\Resident;
use App\Models\User;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('welcome');
});

Route::prefix('admin')
    ->middleware(['auth', 'role:admin'])
    ->group(function () {
        Route::get('/dashboard', function () {
            return view('users');
        })
            ->name('dashboard');

        Route::get('/animations', function () {
            return view('animations');
        })
            ->name('animations');

        Route::get('/residents', function () { 
            return view('residents');
        })
            ->name('residents');

        Route::get('/residents/{residentId}/edit', ResidentEdit::class)
            ->name('resident.edit');

        Route::get('/residents/{residentId}/users',  function ($residentId) {
            $resident = Resident::find($residentId);
            return view('resident-users', ['resident' => $resident]);
        })
            ->name('resident.users');

        Route::get('/user/{userId}/edit', UserEdit::class)
            ->name('users.edit');

        Route::get('/user/{userId}/animations', function ($userId) {
            $user = User::find($userId);
            return view('user-animations', ['user' => $user]);
        })
            ->name('user.animations');
       /* Route::get('/user/{userId}/animations', UserAnimations::class)
            ->name('users.animations');*/

        Route::get('/residents/new', ResidentEdit::class)
            ->name('resident.new');

        Route::get('/user/new', UserEdit::class)
            ->name('users.new');

        Route::get('/animation/{animationId}/edit', AnimationEdit::class)
            ->name('animations.edit');

        Route::get('/animation/{animationId}/users', function ($animationId) {
            $animation = Animation::find($animationId);
            return view('animation-users', ['animation' => $animation]);
        })
            ->name('animation.users');
        /*Route::get('/animation/{animationId}/users', AnimationUsers::class)
            ->name('animations.users');*/

        Route::get('/animation/new', AnimationEdit::class)
            ->name('animations.new');
    });

require __DIR__ . '/auth.php';
